@@ -129,7 +129,12 @@ impl FormulaTerminal {
                 },
             ) if sample_a == sample_b => match (&vafs_a, &vafs_b) {
                 (VAFSpectrum::Range(a), VAFSpectrum::Range(b)) => {
-                    *vafs_a = VAFSpectrum::Range(a & b)
+                    let intersection = a & b;
+                    if intersection.is_singleton() {
+                        *vafs_a = VAFSpectrum::singleton(a.start)
+                    } else {
+                        *vafs_a = VAFSpectrum::Range(a & b)
+                    }
                 }
                 (VAFSpectrum::Range(a), VAFSpectrum::Set(b)) => {
                     *vafs_a = VAFSpectrum::Set(
@@ -396,10 +401,7 @@ impl Formula {
     /// Return true if this formula is a terminal that is always false (an empty VAF set).
     pub(crate) fn is_terminal_false(&self) -> bool {
         match self {
-            Formula::Terminal(FormulaTerminal::Atom {
-                vafs: VAFSpectrum::Set(vafs),
-                ..
-            }) => vafs.is_empty(),
+            Formula::Terminal(FormulaTerminal::Atom { vafs, .. }) => vafs.is_empty(),
             Formula::Terminal(FormulaTerminal::False) => true,
             _ => false,
         }
@@ -578,6 +580,14 @@ impl Formula {
                         for statement in statements.iter() {
                             merged_statement.merge_conjunctions(statement.to_terminal().unwrap());
                         }
+                        // Return false overall if any operand contains an empty spectrum (as this will evaluate to
+                        // a probability of zero).
+                        if let FormulaTerminal::Atom { vafs, .. } = &merged_statement {
+                            if vafs.is_empty() {
+                                return Formula::Terminal(FormulaTerminal::False);
+                            }
+                        }
+
                         *statements = vec![Formula::Terminal(merged_statement)];
                     } else {
                         // non-atoms, apply recursively
@@ -586,14 +596,13 @@ impl Formula {
                         }
                     }
                 }
+                let operands = grouped_operands
+                    .into_iter()
+                    .map(|(_, statements)| statements)
+                    .flatten()
+                    .collect();
 
-                Formula::Conjunction {
-                    operands: grouped_operands
-                        .into_iter()
-                        .map(|(_, statements)| statements)
-                        .flatten()
-                        .collect(),
-                }
+                Formula::Conjunction { operands: operands }
             }
             Formula::Disjunction { operands } => {
                 // collect statements per sample
@@ -1013,12 +1022,21 @@ impl VAFSpectrum {
             VAFSpectrum::Range(ref range) => range.contains(vaf),
         }
     }
+
+    pub(crate) fn is_empty(&self) -> bool {
+        match self {
+            VAFSpectrum::Set(set) => set.is_empty(),
+            VAFSpectrum::Range(range) => range.is_empty(),
+        }
+    }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq, TypedBuilder, Hash)]
+#[derive(Clone, Debug, PartialEq, Eq, TypedBuilder, Hash, CopyGetters)]
 pub(crate) struct VAFRange {
     inner: ops::Range<AlleleFreq>,
+    #[getset(get_copy = "pub")]
     left_exclusive: bool,
+    #[getset(get_copy = "pub")]
     right_exclusive: bool,
 }
 
@@ -1041,6 +1059,14 @@ impl VAFRange {
         }
     }
 
+    pub(crate) fn is_empty(&self) -> bool {
+        self.start == self.end && (self.left_exclusive || self.right_exclusive)
+    }
+
+    pub(crate) fn is_singleton(&self) -> bool {
+        self.start == self.end && !(self.left_exclusive || self.right_exclusive)
+    }
+
     pub(crate) fn contains(&self, vaf: AlleleFreq) -> bool {
         match (self.left_exclusive, self.right_exclusive) {
             (true, true) => self.start < vaf && self.end > vaf,
