@@ -54,12 +54,16 @@ impl Bias for HomopolymerError {
         if !self.is_artifact() {
             return true;
         }
-        // METHOD: this bias is only relevant if there is at least one recorded indel operation (indel operations are only recorded for some variants).
-        pileups.iter().any(|pileup| {
-            pileup
+        // METHOD: we require all alt supporting samples to have at least one homopolymer indel relative to the alt allele.
+        pileups.iter().all(|pileup| {
+            !pileup
                 .read_observations()
                 .iter()
-                .any(|obs| self.is_bias_evidence(obs))
+                .any(|obs| obs.is_strong_alt_support())
+                || pileup
+                    .read_observations()
+                    .iter()
+                    .any(|obs| self.is_bias_evidence(obs))
         })
     }
 
